@@ -2,7 +2,7 @@ package PICA::Path;
 use v5.14.1;
 use utf8;
 
-our $VERSION = '1.24';
+our $VERSION = '1.25';
 
 use Carp qw(confess);
 use Scalar::Util qw(reftype);
@@ -10,53 +10,75 @@ use Scalar::Util qw(reftype);
 use overload '""' => \&stringify;
 
 sub new {
-    my ($class, $path) = @_;
+    my ($class, $path, %options) = @_;
 
     confess "invalid pica path" if $path !~ /
-        ([012.][0-9.][0-9.][A-Z@.]) # tag
-        (\[([0-9.]{2,3})\])?        # occurrence
-        (\$?([_A-Za-z0-9]+))?       # subfields
-        (\/(\d+)?(-(\d+)?)?)?       # position
+        ([012.][0-9.][0-9.][A-Z@.])     # tag
+        (\[([0-9.]{2,3}|\d+-\d+)\])?    # occurrence
+        (\$?([_A-Za-z0-9]+))?           # subfields
+        (\/(\d+)?(-(\d+)?)?)?           # position
     /x;
 
     my $field      = $1;
-    my $occurrence = $3 !~ /^0+$/ ? $3 : undef;
+    my $occurrence = $3;
     my $subfield   = defined $5 ? "[$5]" : "[_A-Za-z0-9]";
 
     my @position;
-    if (defined $6) {    # from, to
-        my ($from, $dash, $to, $length) = ($7, $8, $9, 0);
-
-        if ($dash) {
-            confess "invalid pica path" unless defined($from // $to);    # /-
-        }
-
-        if (defined $to) {
-            if (!$from and $dash) {                                      # /-X
-                $from = 0;
-            }
-            $length = $to - $from + 1;
+    if (defined $6) {    # position
+        if (!defined $occurrence && $options{position_as_occurrence}) {
+            $occurrence = $7 . $8;
         }
         else {
-            if ($8) {
-                $length = undef;
+            my ($from, $dash, $to, $length) = ($7, $8, $9, 0);
+
+            if ($dash) {
+                confess "invalid pica path" unless defined($from // $to); # /-
+            }
+
+            if (defined $to) {
+                if (!$from and $dash) {    # /-X
+                    $from = 0;
+                }
+                $length = $to - $from + 1;
             }
             else {
-                $length = 1;
+                if ($8) {
+                    $length = undef;
+                }
+                else {
+                    $length = 1;
+                }
             }
-        }
 
-        if (!defined $length or $length >= 1) {
-            unless (!$from and !defined $length) {    # /0-
-                @position = ($from, $length);
+            if (!defined $length or $length >= 1) {
+                unless (!$from and !defined $length) {    # /0-
+                    @position = ($from, $length);
+                }
             }
         }
     }
 
     $field = qr{$field};
 
-    if (defined $occurrence) {
-        $occurrence = qr{$occurrence};
+    if ($occurrence =~ /^0+$/) {
+        $occurrence = undef;
+    }
+    elsif (defined $occurrence) {
+        if ($occurrence =~ /-/) {
+            my ($from, $to) = map {1 * $_} split '-', $occurrence;
+            if ($from eq $to) {
+                $occurrence = qr{$from};
+            }
+            elsif ($from < $to) {
+                $occurrence = [$from, $to];
+            }
+            else {
+                confess "invalid pica path";
+            }
+        }
+        else {
+            $occurrence = qr{$occurrence};
+        }
     }
 
     $subfield = qr{$subfield};
@@ -67,8 +89,6 @@ sub new {
 sub match_record {
     my ($self, $record, %args) = @_;
 
-    # my $subfield_regex = $self->[2];
-
     my %default_args = (
         force_array   => 0,
         join          => '',
@@ -131,13 +151,18 @@ sub match_record {
 sub match_field {
     my ($self, $field) = @_;
 
-    if ($field->[0] =~ $self->[0]
-        && (!$self->[1] || ($field->[1] > 0 && $field->[1] =~ $self->[1])))
-    {
-        return $field;
+    return if $field->[0] !~ $self->[0];
+    if (my $spec = $self->[1]) {
+        my $occ = $field->[1];
+        if (ref $spec eq 'ARRAY') {
+            return if $occ < $spec->[0] or $occ > $spec->[1];
+        }
+        else {
+            return unless ($spec > 0 && $occ =~ $spec);
+        }
     }
 
-    return;
+    return $field;
 }
 
 sub match_subfields {
@@ -247,7 +272,9 @@ sub fields {
 }
 
 sub occurrences {
-    return unescape($_[0]->[1]);
+    my $occ = $_[0]->[1];
+    return join "-", @$occ if ref $occ eq 'ARRAY';    # range
+    return unescape($_[0]->[1]);                      # pattern
 }
 
 sub subfields {
@@ -316,7 +343,8 @@ regular expression to match field tags against
 
 =item
 
-regular expression to match occurrences against, or undefined
+regular expression to match occurrences against, or range of occurrences
+values given as array reference (from-to), or undefined
 
 =item
 
@@ -552,7 +580,7 @@ Option C<nested_arrays> creates a list for every field found:
 
 =head1 METHODS
 
-=head2 new( $expression )
+=head2 new( $expression [, position_as_occurrence => 1 ] )
 
 Create a PICA path by parsing the path expression. The expression consists of
 
@@ -580,6 +608,9 @@ supported.
 
 =back
 
+If option C<position_as_occurrence> is set, positions will be read as
+occurrences, e.g. C</2-4> is read as C<[2-4]>.
+
 =head2 match_record( $record, %options )
 
 Returns matched fields as string or array reference. 
